#!/usr/bin/env python
# coding: utf-8

from setuptools import setup

setup(
    name='go-proto-validators',
    version='0.0.1',
    author='supernan1994',
    author_email='supernan1994@gmail.com',
    url='http://supernan1994.github.io/',
    description=u'python compile files for https://github.com/mwitkow/go-proto-validators',
    packages=['github'],
)